class Drawing {

	constructor(canvasID, width, height) {
		this.canvas = document.getElementById(canvasID);
		//Check if the provided arguments have correct values.
		if(this.canvas === null) {
			return new ReferenceError("No element found with ID " + canvasID + ".");
		}
		if(this.canvas.tagName.toUpperCase() !== 'CANVAS') {
			return new TypeError("Element with ID " + canvasID + "is not a canvas element.");
		}
		if(width <= 0) {
			return new RangeError("Width is 0 or less.");
		}
		if(height <= 0) {
			return new RangeError("Height is 0 or less.");
		}

		//Assign width and height.
		this.width  = width;
		this.height = height;

		//Get the drawing context.
		this.context = this.canvas.getContext('2d');

		//Resize the canvas.
		this.canvas.width  = width;
		this.canvas.height = height;

		//Initialize the drawing order array.
		this.drawingOrder = [];
		this.drawingIndex = -1;
	}

	addElement(element) {
		//TODO Check if the argument is indeed an element.
		//TODO Check if the element type has a preload method, and add it to the preload array if necessary.
		this.drawingOrder.push(element);
	}

	draw() {
		this.drawNext();
	}

	drawNext() {
		//Check if there is anything left to draw.
		this.drawingIndex++;
		if(this.drawingOrder[this.drawingIndex] === undefined || typeof this.drawingOrder[this.drawingIndex].draw !== 'function') {
			return;
		}
		this.drawingOrder[this.drawingIndex].draw(this);
	}
}

module.exports = Drawing;